BaseNavigator class abstract

Implemented types

Constructors

BaseNavigator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onGenerateRoute → dynamic
no setteroverride
routeName ↔ String
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRoute(RouteSettings settings) → MaterialPageRoute
override
createWidget(RouteSettings settings, Provider provider) → BaseWidgetState
inherited
landingPage(RouteSettings settings, Provider provider) → BaseWidgetState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited