INavigator class abstract

Implementers

Constructors

INavigator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onGenerateRoute → dynamic
no setter
routeName ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRoute(RouteSettings settings) → MaterialPageRoute
createWidget(RouteSettings settings, Provider provider) → BaseWidgetState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited