BaseWidgetState class abstract

Inheritance
Mixed-in types

Constructors

BaseWidgetState(Provider _provider, {bool isWhitelist = false})

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
goBack → GestureTapCallback
no setter
hashCode → int
The hash code for this object.
no setterinherited
isWhitelist → bool
final
locale → Locale?
no setter
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
no setter
popupMessage ↔ Text?
getter/setter pair
provider → Provider
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedModel → SharedModel
no setter
wantKeepAlive → bool
Whether the current instance should be kept alive.
no setteroverride
widget → BaseWidget
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createDrawer(BuildContext context, List<Widget> children) → Drawer
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant BaseWidget oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
override
goNext(String name, [Object? argument]) → void
initState() → void
Called when this object is inserted into the tree.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback? fn) → void
Notify the framework that the internal state of this object has changed.
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateKeepAlive() → void
Ensures that any AutomaticKeepAlive ancestors are in a good state, by firing a KeepAliveNotification or triggering the KeepAliveHandle as appropriate.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited