SharedModel class

Constructors

SharedModel({required INavigator navigator, ThemeData? theme})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAuthorized ↔ bool
getter/setter pair
locale ↔ Locale?
getter/setter pair
final
routeInfo ↔ RouteInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme ↔ ThemeData
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited